@@ -6,6 +6,7 @@
 #ifndef KTPLUGINACTIVITY_H
 #define KTPLUGINACTIVITY_H
 
+#include <KPluginInfo>
 #include <QWidget>
 #include <interfaces/activity.h>
 
@@ -35,6 +36,7 @@ private Q_SLOTS:
 private:
     PluginManager *pman;
     KPluginSelector *pmw;
+    KPluginInfo::List list;
 };
 
 }
